"""Provides main as the entry point."""

import logging
import os.path
from shutil import copytree
from get_version import get_version
from RPi import GPIO as IO
from . import application
from .paths import ringtones_dir, data_dir
from .db import Settings
from .menus import load_menus, activate_menu
from .ui import loop, on_key, engine
from .modem import modem

cwd = os.path.dirname(__file__)
__version__ = get_version(__package__)


def main():
    with open(os.path.join(data_dir, 'jaspor.log'), 'w') as f:
        logging.basicConfig(stream=f, level='DEBUG')
        logging.debug('Working out of: %s.', cwd)
        logging.info(
            'Active profile: %s.', Settings.active
        )
        if not os.path.isdir(ringtones_dir):
            logging.debug('Creating default ringtones.')
            copytree(
                os.path.join(cwd, 'ringtones'),
                ringtones_dir
            )
        load_menus()
        modem.reset(True)
        activate_menu(None)  # Show call screen.
        on_key(application.lock_key)
        loop.run()
        IO.cleanup()
        engine.endLoop()
