"""
These settings affect how the modem is handled.

Code based on:
https://github.com/lamondlab/IteadSIM800
"""

import re
import os.path
from time import sleep
from RPi import GPIO as IO
from gsmmodem import GsmModem
from .ui import message

port = '/dev/ttyAMA0'
baudrate = 9600
gsm_on = 11
gsm_reset = 12

errors = {}

# Codes found in errors.txt found at:
# https://www.micromedia-int.com/en/gsm-2/73-gsm/669-cme-error-gsm-equipment-related-errors
with open(os.path.join(os.path.dirname(__file__), 'errors.txt'), 'r') as f:
    for code, value in re.findall(
        'CME ERROR[:] ([^\n]+)\n([^\n]+)\n', f.read()
    ):
        errors[int(code)] = value


def get_error_description(exc):
    """Given an exception object returns a description of the CME error."""
    description = errors.get(exc.code, 'Unknown')
    return f'{exc.code} ({description})'


IO.setmode(IO.BOARD)
IO.setup(gsm_on, IO.OUT, initial=IO.LOW)
IO.setup(gsm_reset, IO.OUT, initial=IO.LOW)


class Modem(GsmModem):
    """Add reset method."""

    def reset(self, silent=False):
        """Reset the modem."""
        if not silent:
            message.set_text('Resetting the modem.')
        IO.output(gsm_on, IO.HIGH)
        sleep(1.2)
        IO.output(gsm_on, IO.LOW)
        if not silent:
            message.set_text('Modem reset.')


modem = Modem(port, baudrate=baudrate)
